==> haskell-data-ordlist-0.4.7.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-ordlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-ordlist
version:              0.4.7.0
visibility:           public
id:                   data-ordlist-0.4.7.0-AekMCGPm3QS7HHZRzMfgFe
key:                  data-ordlist-0.4.7.0-AekMCGPm3QS7HHZRzMfgFe
license:              BSD-3-Clause
maintainer:           Leon P Smith <leon@melding-monads.com>
author:               Leon P Smith <leon@melding-monads.com>
synopsis:             Set and bag operations on ordered lists
description:
    This module provides set and multiset operations on ordered lists.

category:             Data, List
abi:                  2703cbe2eb92363dbc727bbddc784382
exposed:              True
exposed-modules:      Data.List.Ordered
import-dirs:          /usr/lib/ghc-8.10.1/site-local/data-ordlist-0.4.7.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/data-ordlist-0.4.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/data-ordlist-0.4.7.0
hs-libraries:         HSdata-ordlist-0.4.7.0-AekMCGPm3QS7HHZRzMfgFe
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-data-ordlist/html/data-ordlist.haddock

haddock-html:         /usr/share/doc/haskell-data-ordlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-ordlist-0.4.7.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-ordlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-ordlist
version:              0.4.7.0
visibility:           public
id:                   data-ordlist-0.4.7.0-2kQWNKO9R932B0kq2odINA
key:                  data-ordlist-0.4.7.0-2kQWNKO9R932B0kq2odINA
license:              BSD-3-Clause
maintainer:           Leon P Smith <leon@melding-monads.com>
author:               Leon P Smith <leon@melding-monads.com>
synopsis:             Set and bag operations on ordered lists
description:
    This module provides set and multiset operations on ordered lists.

category:             Data, List
abi:                  a35eafbe31bf01afad706d561732ac08
exposed:              True
exposed-modules:      Data.List.Ordered
import-dirs:          /usr/lib/ghc-8.10.2/site-local/data-ordlist-0.4.7.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/data-ordlist-0.4.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/data-ordlist-0.4.7.0
hs-libraries:         HSdata-ordlist-0.4.7.0-2kQWNKO9R932B0kq2odINA
depends:              base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-data-ordlist/html/data-ordlist.haddock

haddock-html:         /usr/share/doc/haskell-data-ordlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
